@@ -1,6 +1,25 @@
-/*#####################################################*/
-/*##           modemlights applet 0.3.2              ##*/
-/*#####################################################*/
+/* GNOME modemlights applet
+ * (C) 1999 John Ellis
+ *
+ * Authors: John Ellis
+ *          Martin Baulig
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Cambridge, MA 
+ * 02139, USA.
+ *
+ */
 
 #include "modemlights.h"
 
@@ -13,6 +32,10 @@
 #include <errno.h>
 #include <ctype.h>
 
+#ifdef __OpenBSD__
+#include <net/if_ppp.h>
+#endif
+
 #ifdef __linux__
 #include <linux/isdn.h>
 #include <sys/ioctl.h>
@@ -92,7 +115,7 @@ static void about_cb (AppletWidget *widget, gpointer data)
 	authors[2] = NULL;
 
         about = gnome_about_new ( _("Modem Lights Applet"), version,
-			"(C) 1998",
+			"(C) 1999",
 			authors,
 			_("Released under the GNU general public license.\n"
 			"A modem status indicator and dialer."
@@ -226,22 +249,22 @@ static int get_modem_stats(int *in, int *out)
 	struct 	ppp_stats stats;
 
 	memset(&ifreq, 0, sizeof(ifreq));
-#ifndef __FreeBSD__
-	strncpy(ifreq.ifr_ifrn.ifrn_name, device_name, IFNAMSIZ);
-#else
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
 	strncpy(ifreq.ifr_name, device_name, IFNAMSIZ);
-#endif /* __FreeBSD__ */
+#else
+	strncpy(ifreq.ifr_ifrn.ifrn_name, device_name, IFNAMSIZ);
+#endif /* FreeBSD or OpenBSD */
 	ifreq.ifr_ifru.ifru_data = (caddr_t)&stats;
-#ifndef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__OpenBSD__)
+		if ((ioctl(ip_socket,SIOCGPPPSTATS,(caddr_t)&ifreq) < 0))
+#else
 #ifdef SIOCDEVPRIVATE
 	if ((ioctl(ip_socket,SIOCDEVPRIVATE,(caddr_t)&ifreq) < 0))
 #else
 	*in = *out = 0;
 	return FALSE;
 #endif
-#else
-		if ((ioctl(ip_socket,SIOCGPPPSTATS,(caddr_t)&ifreq) < 0))
-#endif /* __FreeBSD__ */
+#endif /* FreeBSD or OpenBSD */
 			{
 				/* failure means ppp is not up */
 				*in = *out = 0;
