@@ -137,8 +137,6 @@ basep_widget_set_ebox_orient(BasePWidget *basep,
 		break;
 	case ORIENT_DOWN:
 	case ORIENT_RIGHT:
-		xattributes.win_gravity = NorthWestGravity;
-		break;
 	default:
 		xattributes.win_gravity = NorthWestGravity;
 		break;
@@ -158,42 +156,32 @@ move_step(int src, int dest, long start_time, long end_time, long cur_time)
 	if(src == dest)
 		return dest;
 
-	percentage = ((double)(cur_time-start_time))/(end_time-start_time);
-	
-	if(percentage>1.0)
-		percentage = 1.0;
-	
-	return  src + ((dest - src)*percentage);
-}
-
-#if 0
-static int
-move_step(int src, int dest, int pos, int step)
-{
-	int range;
-	int diff;
-	int percentage;
-	int ret;
-	
-	if(src == dest)
-		return 0;
-
-	range = abs(src-dest);
-	diff = abs(range-abs(pos-src));
-	percentage = (diff*100)/range;
-
-	if(percentage>50)
-		percentage = 100-percentage;
-	
-	ret = (src>dest?-1:1)*(((step>>1)*log((percentage/10.0)+1))+1);
-	if(src>dest) {
-		if(ret+pos<dest) ret = dest - pos;
+	if(global_config.simple_movement) {
+		percentage = ((double)(cur_time-start_time))/(end_time-start_time);
+		if(percentage>1.0)
+			percentage = 1.0;
+		return  src + ((dest - src)*percentage);
 	} else {
-		if(ret+pos>dest) ret = dest - pos;
+		double n = cur_time-start_time;
+		double d = end_time-start_time;
+
+		if(n<d) {
+			/*blah blah blah just a simple function to make the
+			  movement more "sin" like ... we run it twice to
+			  pronounce make it more pronounced*/
+			percentage = sin(M_PI*(n/d)-M_PI/2)/2+0.5;
+			percentage = sin(M_PI*percentage-M_PI/2)/2+0.5;
+			if(percentage<0.0)
+				percentage = 0.0;
+			else if(percentage>1.0)
+				percentage = 1.0;
+		} else
+			percentage = 1.0;
+
+		return  src + ((dest - src)*percentage);
 	}
-	return ret;
 }
-#endif
+
 
 void
 basep_widget_do_hiding(BasePWidget *basep, PanelOrientType hide_orient,
@@ -252,7 +240,6 @@ basep_widget_do_hiding(BasePWidget *basep, PanelOrientType hide_orient,
 	}
 
 	if(!pw_disable_animations && step != 0) {
-		int i;
 		GTimeVal tval;
 		long start_secs;
 		long start_time;
@@ -269,7 +256,6 @@ basep_widget_do_hiding(BasePWidget *basep, PanelOrientType hide_orient,
 
 		basep_widget_set_ebox_orient(basep, hide_orient);
 		
-		i = 0;
 		while(x != dx ||
 		      y != dy ||
 		      w != dw ||
@@ -284,13 +270,8 @@ basep_widget_do_hiding(BasePWidget *basep, PanelOrientType hide_orient,
 			w = move_step(ow,dw,start_time,end_time,cur_time);
 			h = move_step(oh,dh,start_time,end_time,cur_time);
 			gdk_window_move_resize(wid->window, x,y,w,h);
-			/*drawing the entire table flickers, so don't
-			  do it often*/
-			if(i++%10)
-				gtk_widget_draw(basep->panel, NULL);
-			else
-				gtk_widget_draw(basep->table, NULL);
 			gdk_flush();
+			usleep(1000);
 		}
 
 		gdk_window_resize(wid->window,dw,dh);
@@ -300,6 +281,7 @@ basep_widget_do_hiding(BasePWidget *basep, PanelOrientType hide_orient,
 		basep_widget_set_ebox_orient(basep, -1);
 	}
 	
+	gtk_widget_queue_resize(wid);
 	gtk_widget_draw(basep->table, NULL);
 }
 
@@ -395,12 +377,14 @@ basep_widget_do_showing(BasePWidget *basep, PanelOrientType hide_orient,
 			
 			cur_time = ((tval.tv_sec-start_secs)*1000000) +
 				tval.tv_usec;
-
+			
 			x = move_step(ox,dx,start_time,end_time,cur_time);
 			y = move_step(oy,dy,start_time,end_time,cur_time);
 			w = move_step(ow,dw,start_time,end_time,cur_time);
 			h = move_step(oh,dh,start_time,end_time,cur_time);
 			gdk_window_move_resize(wid->window, x,y,w,h);
+			gdk_flush();
+			
 			/*drawing the entire table flickers, so don't
 			  do it often*/
 			if(i++%10)
@@ -408,6 +392,7 @@ basep_widget_do_showing(BasePWidget *basep, PanelOrientType hide_orient,
 			else
 				gtk_widget_draw(basep->table, NULL);
 			gdk_flush();
+			usleep(1000);
 		}
 
 		gdk_window_resize(wid->window,dw,dh);
@@ -450,6 +435,8 @@ make_hidebutton(BasePWidget *basep,
 
 	gtk_container_add(GTK_CONTAINER(w),pixmap);
 	gtk_object_set_user_data(GTK_OBJECT(w), pixmap);
+	gtk_object_set_data(GTK_OBJECT(w), "gnome_disable_sound_events",
+			    GINT_TO_POINTER(1));
 	return w;
 }
 
@@ -505,8 +492,6 @@ basep_widget_init (BasePWidget *basep)
 	basep->hidebutton_pixmaps_enabled = TRUE;
 }
 
-
-
 static void
 show_hidebutton_pixmap(GtkWidget *hidebutton, int show)
 {
