@@ -151,24 +151,25 @@ drawer_widget_size_request(GtkWidget *widget,
 {
 	DrawerWidget *drawer = DRAWER_WIDGET(widget);
 	BasePWidget *basep = BASEP_WIDGET(widget);
+	GtkRequisition chreq;
 	int w,h;
 	if(drawer_widget_request_cube) {
-		requisition->width = 48;
-		requisition->height = 48;
+		requisition->width = PANEL_MINIMUM_WIDTH;
+		requisition->height = PANEL_MINIMUM_WIDTH;
 		drawer_widget_request_cube = FALSE;
 		return;
 	}
 
-	gtk_widget_size_request (basep->ebox, &basep->ebox->requisition);
+	gtk_widget_size_request (basep->ebox, &chreq);
 
-	w = basep->ebox->requisition.width;
-	h = basep->ebox->requisition.height;
+	w = chreq.width;
+	h = chreq.height;
 
 	/* do a minimal 48 size*/
 	if(PANEL_WIDGET(basep->panel)->orient == PANEL_HORIZONTAL) {
-		if(w<48) w=48;
+		if(w<PANEL_MINIMUM_WIDTH) w=PANEL_MINIMUM_WIDTH;
 	} else {
-		if(h<48) h=48;
+		if(h<PANEL_MINIMUM_WIDTH) h=PANEL_MINIMUM_WIDTH;
 	}
 	requisition->width = w;
 	requisition->height = h;
@@ -190,9 +191,10 @@ drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 		int px, py, pw, ph;
 		GtkWidget *ppanel; /*parent panel*/
 
-		BasePWidget *basep;
 		
 		/*get the parent of the applet*/
+		/*note we know these are not NO_WINDOW widgets, so
+		  we don't need to check*/
 		ppanel = panel->master_widget->parent;
 		bx = panel->master_widget->allocation.x +
 			ppanel->allocation.x;
@@ -201,15 +203,11 @@ drawer_widget_get_pos(DrawerWidget *drawer, gint16 *x, gint16 *y,
 		/*go the the toplevel panel widget*/
 		while(ppanel->parent) {
 			ppanel = ppanel->parent;
-			bx += ppanel->allocation.x;
-			by += ppanel->allocation.y;
+			if(!GTK_WIDGET_NO_WINDOW(ppanel)) {
+				bx += ppanel->allocation.x;
+				by += ppanel->allocation.y;
+			}
 		}
-		basep = BASEP_WIDGET(ppanel);
-		/*a hack as the above just doesn't work perfectly*/
-		if(GTK_WIDGET_VISIBLE(basep->hidebutton_n))
-			by -= basep->hidebutton_n->allocation.height;
-		if(GTK_WIDGET_VISIBLE(basep->hidebutton_w))
-			bx -= basep->hidebutton_w->allocation.width;
 
 		bw = panel->master_widget->allocation.width;
 		bh = panel->master_widget->allocation.height;
@@ -249,21 +247,21 @@ drawer_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	DrawerWidget *drawer = DRAWER_WIDGET(widget);
 	BasePWidget *basep = BASEP_WIDGET(widget);
 	GtkAllocation challoc;
+	GtkRequisition chreq;
 	int w,h;
 
 	/*we actually want to ignore the size_reqeusts since they
 	  are sometimes a cube for the flicker prevention*/
-	gtk_widget_size_request (basep->ebox,
-				 &basep->ebox->requisition);
+	gtk_widget_size_request (basep->ebox, &chreq);
 
-	w = basep->ebox->requisition.width;
-	h = basep->ebox->requisition.height;
+	w = chreq.width;
+	h = chreq.height;
 
 	/* do a minimal 48 size*/
 	if(PANEL_WIDGET(basep->panel)->orient == PANEL_HORIZONTAL) {
-		if(w<48) w=48;
+		if(w<PANEL_MINIMUM_WIDTH) w=PANEL_MINIMUM_WIDTH;
 	} else {
-		if(h<48) h=48;
+		if(h<PANEL_MINIMUM_WIDTH) h=PANEL_MINIMUM_WIDTH;
 	}
 	allocation->width = w;
 	allocation->height = h;
