@@ -229,6 +229,15 @@ sal(GtkWidget *applet, GtkAllocation *alloc)
 	       applet->allocation.height);
 }*/
 
+static void
+test_size(GtkWidget *applet, GtkAllocation *alloc)
+{
+	if(applet->allocation.width > applet->requisition.width ||
+	   applet->allocation.height > applet->requisition.height) {
+		gtk_widget_queue_resize(applet->parent);
+	}
+}
+
 /*note that type should be APPLET_EXTERN_RESERVED or APPLET_EXTERN_PENDING
   only*/
 static CORBA_unsigned_long
@@ -245,6 +254,9 @@ reserve_applet_spot (Extern *ext, PanelWidget *panel, int pos,
 
 	socket = gtk_socket_new();
 
+	gtk_signal_connect_after(GTK_OBJECT(socket),"size_allocate",
+				 GTK_SIGNAL_FUNC(test_size),NULL);
+
 	/*gtk_signal_connect_after(GTK_OBJECT(socket),"size_allocate",
 				 GTK_SIGNAL_FUNC(sal),NULL);*/
 
@@ -710,39 +722,51 @@ panel_corba_clean_up(void)
   CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
 }
 
-void
+gint
 panel_corba_gtk_init(CORBA_ORB panel_orb)
 {
   GNOME_Panel acc;
   char hostname [4096];
   char *name;
-  CORBA_Object ns;
+  CORBA_Object ns, old_server;
+  gint status;
 
   CORBA_exception_init(&ev);
 
   orb = panel_orb;
 
   POA_GNOME_Panel__init(&panel_servant, &ev);
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
 
   thepoa = (PortableServer_POA)
     CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
 
   PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(thepoa, &ev), &ev);
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
 
   CORBA_free(PortableServer_POA_activate_object(thepoa,
 						&panel_servant, &ev));
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
 
   acc = PortableServer_POA_servant_to_reference(thepoa, &panel_servant, &ev);
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
 
-  goad_server_register(CORBA_OBJECT_NIL, acc, "gnome_panel", "server", &ev);
+  old_server = goad_server_activate_with_repo_id (NULL, "IDL:GNOME/Panel:1.0", 
+						  GOAD_ACTIVATE_EXISTING_ONLY,
+						  NULL);
+
+  if(! CORBA_Object_is_nil(old_server, &ev)) {
+    CORBA_Object_release(old_server, &ev);
+    return -4;
+  }
+
+  status = goad_server_register(CORBA_OBJECT_NIL, acc, "gnome_panel", "server", &ev);
 
   /*
-  //CORBA_Object_release(acc, &ev);
+  CORBA_Object_release(acc, &ev);
   */
-  g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+  g_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, -1);
+
+  return status;
 }
