@@ -18,9 +18,10 @@
 #include <gnome.h>
 
 #include "panel-include.h"
+#include "panel-widget.h"
 
 #define SMALL_ICON_SIZE 20
-#define BIG_ICON_SIZE   48
+#define BIG_ICON_SIZE   PANEL_MINIMUM_WIDTH
 
 
 #define MENU_PATH "menu_path"
@@ -502,7 +503,7 @@ init_menus(void)
 	/*just load the menus from disk, don't make the widgets
 	  this just reads the .desktops of the top most directory
 	  and a level down*/
-	char *menu = gnome_datadir_file("apps");
+	char *menu = gnome_datadir_file("gnome/apps");
 	if(menu)
 		fr_read_dir(NULL,menu,NULL,2);
 	g_free(menu);
@@ -1971,7 +1972,7 @@ create_add_panel_submenu (void)
 static GtkWidget *
 create_system_menu(GtkWidget *menu, int fake_submenus, int fake)
 {
-	char *menu_base = gnome_unconditional_datadir_file ("apps");
+	char *menu_base = gnome_unconditional_datadir_file ("gnome/apps");
 	char *menudir;
 	
 	menudir = g_concat_dir_and_file (menu_base, ".");
@@ -1987,8 +1988,9 @@ create_system_menu(GtkWidget *menu, int fake_submenus, int fake)
 		}
 		g_return_val_if_fail(menu,NULL);
 		g_free (menudir);
-	} else
+	} else {
 		g_warning("No system menus found!");
+	}
 	
 	return menu;
 }
@@ -2029,10 +2031,12 @@ create_panel_root_menu(GtkWidget *panel)
 	setup_menuitem (menuitem, 0, _("System menus"));
 	gtk_menu_append (GTK_MENU (panel_menu), menuitem);
 	menu = create_system_menu(NULL,TRUE,TRUE);
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),menu);
-	gtk_signal_connect(GTK_OBJECT(menu),"show",
-			   GTK_SIGNAL_FUNC(submenu_to_display),
-			   menuitem);
+	if(menu) {
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),menu);
+		gtk_signal_connect(GTK_OBJECT(menu),"show",
+				   GTK_SIGNAL_FUNC(submenu_to_display),
+				   menuitem);
+	}
 
 	menuitem = gtk_menu_item_new ();
 	setup_menuitem (menuitem, 0, _("User menus"));
@@ -2787,10 +2791,13 @@ create_root_menu(int fake_submenus, int flags)
 		menuitem = gtk_menu_item_new ();
 		setup_menuitem (menuitem, 0, _("System menus"));
 		gtk_menu_append (GTK_MENU (root_menu), menuitem);
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
-		gtk_signal_connect(GTK_OBJECT(menu),"show",
-				   GTK_SIGNAL_FUNC(submenu_to_display),
-				   menuitem);
+		if(menu) {
+			gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
+						   menu);
+			gtk_signal_connect(GTK_OBJECT(menu),"show",
+					   GTK_SIGNAL_FUNC(submenu_to_display),
+					   menuitem);
+		}
 	}
 	if(flags&MAIN_MENU_USER && flags&MAIN_MENU_USER_SUB) {
 		if(need_separ)
@@ -2870,7 +2877,7 @@ menu_button_pressed(GtkWidget *widget, gpointer data)
 	current_panel = PANEL_WIDGET(menu->button->parent);
 
 	if(!menu->menu) {
-		char *menu_base = gnome_unconditional_datadir_file ("apps");
+		char *menu_base = gnome_unconditional_datadir_file ("gnome/apps");
 		char *this_menu = get_real_menu_path(menu->path,menu_base);
 		GSList *list = g_slist_append(NULL,this_menu);
 		
@@ -2976,7 +2983,7 @@ create_menu_applet(char *arguments, PanelOrientType orient,
 	Menu *menu;
 	int main_menu;
 
-	char *menu_base = gnome_unconditional_datadir_file ("apps");
+	char *menu_base = gnome_unconditional_datadir_file ("gnome/apps");
 	char *this_menu = get_real_menu_path(arguments,menu_base);
 
 	if (!this_menu) {
@@ -3075,7 +3082,7 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 	menu->menu = NULL;
 
 	{
-		char *menu_base = gnome_unconditional_datadir_file ("apps");
+		char *menu_base = gnome_unconditional_datadir_file ("gnome/apps");
 		char *this_menu = get_real_menu_path(menu->path,menu_base);
 		GSList *list = g_slist_append(NULL,this_menu);
 		char *pixmap_name = get_pixmap(this_menu,
@@ -3208,14 +3215,14 @@ create_properties_dialog(Menu *menu)
 	/*gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);*/
 	gtk_window_set_policy(GTK_WINDOW(dialog), FALSE, FALSE, TRUE);
 	
-	vbox = gtk_vbox_new(FALSE,5);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),5);
+	vbox = gtk_vbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),GNOME_PAD_SMALL);
 
 	f = gtk_frame_new(_("Menu type"));
 	gtk_box_pack_start(GTK_BOX(vbox),f,FALSE,FALSE,0);
 	
-	box = gtk_hbox_new(FALSE,5);
-	gtk_container_set_border_width(GTK_CONTAINER(box),5);
+	box = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(box),GNOME_PAD_SMALL);
 	gtk_container_add(GTK_CONTAINER(f),box);
 	
 	w = gtk_radio_button_new_with_label (NULL, _("Main menu"));
@@ -3245,7 +3252,7 @@ create_properties_dialog(Menu *menu)
 	gtk_box_pack_start(GTK_BOX(vbox),f,FALSE,FALSE,0);
 	
 	table = gtk_table_new(3,4,FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER(table),5);
+	gtk_container_set_border_width(GTK_CONTAINER(table),GNOME_PAD_SMALL);
 	gtk_container_add(GTK_CONTAINER(f),table);
 
 	add_menu_type_options(GTK_OBJECT(dialog),GTK_TABLE(table),0,
@@ -3267,8 +3274,8 @@ create_properties_dialog(Menu *menu)
 	gtk_object_set_data(GTK_OBJECT(dialog),"normal_frame",f);
 	gtk_box_pack_start(GTK_BOX(vbox),f,FALSE,FALSE,0);
 	
-	box = gtk_hbox_new(FALSE,5);
-	gtk_container_set_border_width(GTK_CONTAINER(box),5);
+	box = gtk_hbox_new(FALSE,GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(box),GNOME_PAD_SMALL);
 	gtk_container_add(GTK_CONTAINER(f),box);
 	
 	w = gtk_label_new(_("Menu path"));
@@ -3344,6 +3351,8 @@ get_menu_position (GtkMenu *menu, int *x, int *y,
 		   int wx, int wy, int ww, int wh,
 		   GtkWidget *pwidget)
 {
+	GtkRequisition mreq;
+	gtk_widget_get_child_requisition(GTK_WIDGET(menu),&mreq);
 	if(IS_DRAWER_WIDGET(pwidget)) {
 		PanelWidget *panel =
 			PANEL_WIDGET(BASEP_WIDGET(pwidget)->panel);
@@ -3352,13 +3361,13 @@ get_menu_position (GtkMenu *menu, int *x, int *y,
 			*y += wy;
 		} else {
 			*x += wx;
-			*y = wy - GTK_WIDGET (menu)->requisition.height;
+			*y = wy - mreq.height;
 		}
 	} else if(IS_SNAPPED_WIDGET(pwidget)) {
 		switch(SNAPPED_WIDGET(pwidget)->pos) {
 		case SNAPPED_BOTTOM:
 			*x += wx;
-			*y = wy - GTK_WIDGET (menu)->requisition.height;
+			*y = wy - mreq.height;
 			break;
 		case SNAPPED_TOP:
 			*x += wx;
@@ -3369,7 +3378,7 @@ get_menu_position (GtkMenu *menu, int *x, int *y,
 			*y += wy;
 			break;
 		case SNAPPED_RIGHT:
-			*x = wx - GTK_WIDGET (menu)->requisition.width;
+			*x = wx - mreq.width;
 			*y += wy;
 			break;
 		}
@@ -3381,7 +3390,7 @@ get_menu_position (GtkMenu *menu, int *x, int *y,
 			case CORNER_SE:
 			case CORNER_SW:
 				*x += wx;
-				*y = wy - GTK_WIDGET (menu)->requisition.height;
+				*y = wy - mreq.height;
 				break;
 			case CORNER_NE:
 			case CORNER_NW:
@@ -3398,19 +3407,19 @@ get_menu_position (GtkMenu *menu, int *x, int *y,
 				break;
 			case CORNER_NE:
 			case CORNER_SE:
-				*x = wx - GTK_WIDGET (menu)->requisition.width;
+				*x = wx - mreq.width;
 				*y += wy;
 				break;
 			}
 		}
 	}
 
-	if(*x + GTK_WIDGET (menu)->requisition.width > gdk_screen_width())
-		*x=gdk_screen_width() - GTK_WIDGET (menu)->requisition.width;
+	if(*x + mreq.width > gdk_screen_width())
+		*x=gdk_screen_width() - mreq.width;
 	if(*x < 0) *x =0;
 
-	if(*y + GTK_WIDGET (menu)->requisition.height > gdk_screen_height())
-		*y=gdk_screen_height() - GTK_WIDGET (menu)->requisition.height;
+	if(*y + mreq.height > gdk_screen_height())
+		*y=gdk_screen_height() - mreq.height;
 	if(*y < 0) *y =0;
 }
 
