@@ -670,26 +670,19 @@ panel_widget_size_request(GtkWidget *widget, GtkRequisition *requisition)
 
 	for(list = panel->applet_list; list!=NULL; list = g_list_next(list)) {
 		AppletData *ad = list->data;
-		gtk_widget_size_request (ad->applet, &ad->applet->requisition);
+		GtkRequisition chreq;
+		gtk_widget_size_request(ad->applet,&chreq);
 		if(panel->orient == PANEL_HORIZONTAL) {
-			if(requisition->height <
-			   ad->applet->requisition.height) {
-				requisition->height =
-					ad->applet->requisition.height;
-			}
+			if(requisition->height < chreq.height)
+				requisition->height = chreq.height;
 			if(panel->packed)
-				requisition->width +=
-					ad->applet->requisition.width +
+				requisition->width += chreq.width +
 					pw_applet_padding;
 		} else {
-			if(requisition->width <
-			   ad->applet->requisition.width) {
-				requisition->width =
-					ad->applet->requisition.width;
-			}
+			if(requisition->width < chreq.width)
+				requisition->width = chreq.width;
 			if(panel->packed)
-				requisition->height +=
-					ad->applet->requisition.height +
+				requisition->height += chreq.height +
 					pw_applet_padding;
 		}
 	}
@@ -857,6 +850,37 @@ panel_widget_expose(GtkWidget *widget, GdkEventExpose *event)
 	return FALSE;
 }
 
+static int
+fit_pix_timeout(gpointer data)
+{
+	PanelWidget *panel = data;
+	if(panel->pixmap_resize_pending &&
+	   panel->fit_pixmap_bg &&
+	   panel->back_type == PANEL_BACK_PIXMAP) {
+		panel_resize_pixmap(panel);
+		panel->pixmap_resize_pending = FALSE;
+		return TRUE;
+	}
+	panel->pixmap_resize_timeout = 0;
+	panel->pixmap_resize_pending = FALSE;
+	return FALSE;
+}
+
+static int
+fit_pix_timeout_top(gpointer data)
+{
+	PanelWidget *panel = data;
+	if(panel->pixmap_resize_timeout ||
+	   !panel->fit_pixmap_bg ||
+	   panel->back_type != PANEL_BACK_PIXMAP)
+		return FALSE;
+	panel_resize_pixmap(panel);
+	panel->pixmap_resize_pending = FALSE;
+	panel->pixmap_resize_timeout =
+		gtk_timeout_add(2000,fit_pix_timeout,panel);
+	return FALSE;
+}
+
 static void
 panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
@@ -899,24 +923,24 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		    list = g_list_next(list)) {
 			AppletData *ad = list->data;
 			GtkAllocation challoc;
+			GtkRequisition chreq;
+			gtk_widget_get_child_requisition(ad->applet,&chreq);
 			
 			if(i != ad->pos) {
 				ad->pos = i;
 				send_move = g_slist_prepend(send_move,ad);
 			}
 			if(panel->orient == PANEL_HORIZONTAL) {
-				ad->cells = ad->applet->requisition.width +
-					pw_applet_padding;
+				ad->cells = chreq.width + pw_applet_padding;
 				challoc.x = ad->pos;
-				challoc.y = (allocation->height - ad->applet->requisition.height) / 2;
+				challoc.y = (allocation->height - chreq.height) / 2;
 			} else {
-				ad->cells = ad->applet->requisition.height +
-					pw_applet_padding;
-				challoc.x = (allocation->width - ad->applet->requisition.width) / 2;
+				ad->cells = chreq.height + pw_applet_padding;
+				challoc.x = (allocation->width - chreq.width) / 2;
 				challoc.y = ad->pos;
 			}
-			challoc.width = ad->applet->requisition.width;
-			challoc.height = ad->applet->requisition.height;
+			challoc.width = chreq.width;
+			challoc.height = chreq.height;
 			gtk_widget_size_allocate(ad->applet,&challoc);
 			i += ad->cells;
 		}
@@ -926,13 +950,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		    list!=NULL;
 		    list = g_list_previous(list)) {
 			AppletData *ad = list->data;
+			GtkRequisition chreq;
+			gtk_widget_get_child_requisition(ad->applet,&chreq);
 			
 			if(panel->orient == PANEL_HORIZONTAL)
-				ad->cells = ad->applet->requisition.width +
-					pw_applet_padding;
+				ad->cells = chreq.width + pw_applet_padding;
 			else
-				ad->cells = ad->applet->requisition.height +
-					pw_applet_padding;
+				ad->cells = chreq.height + pw_applet_padding;
 			if(ad->pos+ad->cells > i) {
 				ad->pos = i - ad->cells;
 				send_move = g_slist_prepend(send_move,ad);
@@ -961,15 +985,17 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		    list = g_list_next(list)) {
 			AppletData *ad = list->data;
 			GtkAllocation challoc;
+			GtkRequisition chreq;
+			gtk_widget_get_child_requisition(ad->applet,&chreq);
 			if(panel->orient == PANEL_HORIZONTAL) {
 				challoc.x = ad->pos;
-				challoc.y = (allocation->height - ad->applet->requisition.height) / 2;
+				challoc.y = (allocation->height - chreq.height) / 2;
 			} else {
-				challoc.x = (allocation->width - ad->applet->requisition.width) / 2;
+				challoc.x = (allocation->width - chreq.width) / 2;
 				challoc.y = ad->pos;
 			}
-			challoc.width = ad->applet->requisition.width;
-			challoc.height = ad->applet->requisition.height;
+			challoc.width = chreq.width;
+			challoc.height = chreq.height;
 			gtk_widget_size_allocate(ad->applet,&challoc);
 		}
 	}
@@ -980,8 +1006,13 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 
 	if(old_thick != panel->thick &&
 	   panel->fit_pixmap_bg &&
-	   panel->back_type == PANEL_BACK_PIXMAP)
-		panel_resize_pixmap(panel);
+	   panel->back_type == PANEL_BACK_PIXMAP) {
+		if(panel->pixmap_resize_timeout)
+			panel->pixmap_resize_pending = TRUE;
+		else {
+			gtk_timeout_add(500,fit_pix_timeout_top,panel);
+		}
+	}
 
 	
 	for(li=send_move;li!=NULL;li=g_slist_next(li)) {
@@ -1065,12 +1096,7 @@ panel_try_to_set_default_back(PanelWidget *panel)
 	g_return_if_fail(panel!=NULL);
 	g_return_if_fail(IS_PANEL_WIDGET(panel));
 
-	ns = gtk_rc_get_style(GTK_WIDGET(panel));
-	if(!ns) ns = gtk_style_new();
-
-	gtk_style_ref(ns);
-	gtk_widget_set_style(GTK_WIDGET(panel), ns);
-	gtk_style_unref(ns);
+	gtk_widget_set_rc_style(GTK_WIDGET(panel));
 
 	panel_widget_draw_all(panel);
 }
@@ -1162,6 +1188,8 @@ panel_resize_pixmap(PanelWidget *panel)
 	gtk_widget_set_style(GTK_WIDGET(panel), ns);
 	
 	gtk_style_unref(ns);
+
+	panel_widget_draw_all(panel);
 }
 
 static int
@@ -1348,6 +1376,8 @@ panel_widget_init (PanelWidget *panel)
 
 	panel->back_type =PANEL_BACK_NONE;
 	panel->fit_pixmap_bg = FALSE;
+	panel->pixmap_resize_timeout = 0;
+	panel->pixmap_resize_pending = FALSE;
 	panel->back_pixmap = NULL;
 	panel->back_color.red = 0;
 	panel->back_color.green = 0;
@@ -1769,11 +1799,16 @@ panel_widget_applet_move_to_cursor(PanelWidget *panel)
 static int
 move_timeout_handler(gpointer data)
 {
+	PanelWidget *panel = data;
 	g_return_val_if_fail(data!=NULL,FALSE);
 	g_return_val_if_fail(IS_PANEL_WIDGET(data),FALSE);
 	
-	if(been_moved)
-		panel_widget_applet_move_to_cursor(PANEL_WIDGET(data));
+	if(been_moved &&
+	   panel->currently_dragged_applet) {
+		panel_widget_applet_move_to_cursor(panel);
+		been_moved = FALSE;
+		return TRUE;
+	}
 	been_moved = FALSE;
 	moving_timeout = -1;
 	
